/*
  Copyright (C) 2006   Hans-Georg Breunig

  This file is part of TsumeGo.

  TsumeGo is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  TsumeGo is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with TsumeGo; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


#include <stdio.h>

#include "board.h"


void load(char *filename) {
	FILE *f;
	int ch;
	int col = 0, line = 0;

	f = fopen(filename, "r");
	if(f == NULL) {
		printf("Cannot open input file: `%s'.\n", filename);
		exit(-1);
	}

	while((ch = fgetc(f)) != EOF) {
		switch(ch) {
			case 'X':
				board[BPOS(line,col)] = 1;
				col++;
				break;
			case 'O':
				board[BPOS(line,col)] = 2;
				col++;
				break;
			case '.':
				board[BPOS(line,col)] = 0;
				col++;
				break;
		}
		if(col == 4) {
			col = 0;
			line++;
		}
	}
}

// vim:tabstop=4:shiftwidth=4
